
#		Pymol script for analyzing the complex of EcoRI with DNA
#		based on PDB entry 1ERI and 1QPS
#		Chelsea Walker, Graduate Student
#		Loren WIlliams, Georgia Tech
#		Reference:
#	X-RAY STRUCTURE OF THE DNA-ECO RI ENDONUCLEASE-DNA
#	RECOGNITION COMPLEX: THE RECOGNITION NETWORK AND THE
#	INTEGRATION OF RECOGNITION AND CLEAVAGE

reinitialize
bg_color white

load 1eri.pdb1

create Dimer1, Chain A or Chain B
create Dimer2, Chain C or Chain D
create Complex, Dimer1 or Dimer2


#-----Dimers
hide everything, Dimer1
show cartoon, Dimer1
hide everything, Dimer2
show cartoon, Dimer2

#-----Complex
create Complex, Dimer1 or Dimer2
hide everything, Complex
show cartoon, Complex


#-----stick DNA
# DNA Chains B + C
# Protein Chains A + D
create DNA, (chain B or chain C) and Complex
color orange, name C* and DNA
hide everything, DNA
show stick, DNA
 
#-----cartoon protein
# DNA Chains B + C
# Protein Chains A + D
create protein, (chain A or chain D) and Complex
hide everything, protein
show cartoon, protein

#-----Surface Protein
create SurfaceProtein, protein
hide everything, SurfaceProtein
show surface, SurfaceProtein
color palecyan, SurfaceProtein


#-----Watson-Crick H-bonds
distance WC_Hbond, (name O2,N3,N4 and resn DC and DNA), (name N2,N1,O6 and resn DG and DNA ), 3.1
distance WC_Hbond, (name N3,O4 and resn DT and DNA), (name N1,N6 and resn DA and DNA), 3.1
color black, WC_Hbond
hide labels, WC_Hbond
set dash_width, 3
set dash_gap, 0.4
disable WC_Hbond

#-----Protein-DNA H-bonds
distance H_Bond_DNA_Protein, (protein and name O*,N*), (DNA and name O*,N* ), 3.4
color black, H_Bond_DNA_Protein


#-----Protein DNA Interface
create iface, /protein//*/GLY`116 + /protein//*/LYS`148 + /protein//*/LYS`113 + /protein//*/ARG`145 + /protein//*/LYS`117 + /protein//*/SER`87 + /protein//*/ASN`85 + /protein//*/LYS`89 + /protein//*/ASP`91 + /protein//*/ASN`141 + /protein//*/ALA`138 + /protein//*/ALA`139 + /protein//*/LYS`130 + /protein//+/GLY`196 + /protein//*/ARG`203 + /protein//*/GLY`196 + /protein//*/ALA`142 + protein//*/HIS`114
hide everything, iface
show stick, iface
color purple, iface
disable iface

#-----Crosstalk Ring
create xtalk, /protein//*/ARG`145 + /protein//*/GLU`144 + /protein//*/ARG`145 + /protein//A/GLU`144
hide everything, xtalk
show stick, xtalk
color wheat, name C* and xtalk


#-----Recognition Sequence
create Rec_Sequ, /DNA//*/DG`5 + /DNA//*/DA`6 + /DNA//*/DA`7 + /DNA//*/DT`8 + /DNA//*/DT`9 + DNA//*/DC`10
hide everything, Rec_Sequ
show stick, Rec_Sequ
color yellow, name C* and Rec_Sequ
disable Rec_Sequ

#-----Cleaved Fragment
load 1QPS.pdb, Cleaved
hide everything, Cleaved
show cartoon, Cleaved
color gray50, Cleaved
hide everything, /Cleaved//M/DG`5
show stick, /Cleaved//M/DG`5
color red, /Cleaved//M/DG`5
hide everything, /Cleaved//N/DA`6
show stick, /Cleaved//N/DA`6
color red, /Cleaved//N/DA`6
hide everything, /Cleaved//A/GLU`111
show stick, /Cleaved//A/GLU`111
color green, /Cleaved//A/GLU`111



#-----Active Site
create ActiveSite, /Cleaved//A/ASP`91 + /Cleaved//A/GLU`111 + /Cleaved//A/ALA`112
hide everything, ActiveSite
show stick, ActiveSite
color marine, ActiveSite


delete Dimer1
delete Dimer2

disable all
enable SurfaceProtein
enable DNA

set_view (\
     0.875864744,   -0.076935723,   -0.476385295,\
    -0.472406626,    0.064723067,   -0.879000723,\
     0.098458946,    0.994933426,    0.020342579,\
     0.000000000,    0.000000000, -161.676101685,\
    22.659120560,   39.246791840,    0.000000000,\
   113.493927002,  209.858245850,    0.000000000 )
### cut above here and paste into script ###  

#ray 800,800

#save 1ERIduplex.png
